@@ -1,7 +1,7 @@
 from typing import List
 
 from .components import CrudComponent, MetablockEntity
-from .spaces import ServicePlugin
+from .spaces import BlockPlugin
 
 
 # Extension
@@ -19,7 +19,7 @@ class Extensions(CrudComponent):
 class Plugin(MetablockEntity):
     """Object representing an Plugin"""
 
-    async def blocks(self) -> List[ServicePlugin]:
+    async def blocks(self) -> List[BlockPlugin]:
         return await self.get(f"{self.url}/services")
 
 
